window.Gleam.initSearch([{"doc":"glency","title":"glency","content":"# glency\n\n[![Package Version](https://img.shields.io/hexpm/v/glency)](https://hex.pm/packages/glency)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/glency/)\n![Erlang-compatible](https://img.shields.io/badge/target-erlang-a2003e)\n![JavaScript-compatible](https://img.shields.io/badge/target-javascript-f1e05a)\n\nTiny Gleam dependency injection. Make IO functions unit tests friendly.\n\n```sh\ngleam add glency\n```\n\n```gleam\nimport glency\n\ntype Cat {\n  Cat(name: String, age: Int)\n}\n\npub fn main() {\n  glency.init_di() // Firstly init DI container on application startup\n\n  {\n    // Mock implementation of `fetch_cat`\n    use &lt;- glency.with_di(fetch_cat, fn(_cat_id) { Cat(&quot;Barsik&quot;, 7) })\n    fetch_cat(1) // will avoid IO, returns Barsik cat\n  }\n}\n\npub fn fetch_cat(cat_id: Int) {\n  use &lt;- glency.di(fetch_cat, #(cat_id)) // Make IO function DI friendly\n  // Here production IO implementation of function\n}\n```\n\nFurther documentation can be found at &lt;https://hexdocs.pm/glency&gt;.\n\n## Development\n\n```sh\ngleam run   # Run the project\ngleam test  # Run the tests\ngleam shell # Run an Erlang shell\n```\n","url":"index.html"},{"doc":"glency","title":"di","content":"pub fn di(key: a, args: b, cb: fn() -&gt; c) -&gt; c\n\nSynonyms:\nglency.di\nglency di","url":"glency.html#di"},{"doc":"glency","title":"init_di","content":"pub fn init_di() -&gt; Nil\n\nSynonyms:\nglency.init_di\nglency init_di","url":"glency.html#init_di"},{"doc":"glency","title":"with_di","content":"pub fn with_di(key: a, mock: a, cb: fn() -&gt; b) -&gt; Nil\n\nSynonyms:\nglency.with_di\nglency with_di","url":"glency.html#with_di"},{"doc":"glency","title":"glency","content":"","url":"glency.html"}]);